<?php
/**
 * @file
 * Implements the configuration of the Cookie Control pop-up dialog.
 *
 * Module developed by Ixis www.ixis.co.uk
 * JavaScript by Civic UK www.civicuk.com
 */

/**
 * cookicontrol_admin_settings function.
 *
 * @access public
 * @return void
 */
function cookiecontrol_admin_settings() {
  $form = array();
  $path = drupal_get_path('module', 'cookiecontrol');

  $form['interface'] = array(
    '#type' => 'fieldset',
    '#title' => t('User Interface'),
  );
  $form['interface']['cookiecontrol_text'] = array(
    '#type' => 'textarea',
    '#title' => t('Text'),
    '#default_value' => variable_get('cookiecontrol_text', COOKIECONTROL_TEXT),
    '#description' => t('A short message about the use of cookies on this site. HTML markup is allowed.'),
    '#required' => TRUE,
  );

  $cookiecontrol_privacynode = variable_get('cookiecontrol_privacynode', '');
  $form['interface']['cookiecontrol_privacynode'] = array(
    '#type' => 'textfield',
    '#size' => 5,
    '#maxlength' => 7,
    '#title' => t('Privacy Policy Link'),
    '#field_prefix' => '?q=node/',
    '#default_value' => $cookiecontrol_privacynode,
    '#description' => t("Specify a node id which represents your site's privacy policy. This will be appended to the message text above."),
    '#required' => FALSE,
  );
  // Display a link to the current privacy policy if set
  if ($cookiecontrol_privacynode > 0) {
    $form['interface']['cookiecontrol_privacynode']['#field_suffix'] = l(t('View existing privacy policy page'), 'node/' . $cookiecontrol_privacynode, array('attributes' => array('target' => 'new')));
  }

  $form['interface']['cookiecontrol_shape'] = array(
    '#type' => 'radios',
    '#title' => t('Icon Shape'),
    '#description' => t("The icon will be anchored to the corner of the viewport and won't scroll with your web page."),
    '#default_value' => variable_get('cookiecontrol_shape', 'triangle'),
    '#options' => array(
      'triangle' => t('!icon Triangle', array('!icon' => theme('image', array('path' => $path . '/images/icon-triangle.png')))),
      'diamond' => t('!icon Diamond', array('!icon' => theme('image', array('path' => $path . '/images/icon-diamond.png'))))
    )
  );

  $form['interface']['cookiecontrol_position'] = array(
    '#type' => 'radios',
    '#title' => t('Icon Position'),
    '#description' => t("Choose whether you'd like your icon to appear on the bottom left or botom right of the browser window."),
    '#default_value' => variable_get('cookiecontrol_position', 'left'),
    '#options' => array(
      'left' => t('Left'),
      'right' => t('Right'),
    )
  );

  $form['visibility'] = array(
    '#type' => 'fieldset',
    '#title' => t('Visibility'),
  );
  $form['visibility']['cookiecontrol_startopen'] = array(
    '#type' => 'checkbox',
    '#title' => t('Open the cookie information on page load.'),
    '#default_value' => variable_get('cookiecontrol_startopen', TRUE),
    '#description' => t('Visitors to the site will see the pop-up at the bottom of their browser on every page load until they acknowledge the pop-up.')
  );
  $form['visibility']['cookiecontrol_timeout'] = array(
    '#type' => 'textfield',
    '#size' => 5,
    '#title' => t('Automatic Hide Timeout'),
    '#field_suffix' => t('seconds'),
    '#default_value' => variable_get('cookiecontrol_timeout', '60'),
    '#description' => t("How long to keep the information pop-up displayed before it is automatically hidden. Once hidden the information can be accessed by clicking on the icon in the corner."),
    '#required' => FALSE,
  );
  $form['visibility']['cookiecontrol_countries'] = array(
    '#type' => 'textfield',
    '#title' => t('Country Restriction'),
    '#default_value' => variable_get('cookiecontrol_countries', ''),
    '#description' => t('Enter a comma separated list of countries for which you wish the pop-up to appear. If left blank Cookie Control will appear for all users from all countries. The full list of countries can be found !here.', array('!here' => l(t('here'), 'http://www.geoplugin.com/iso3166'))),
  );

  return system_settings_form($form);
}

/**
 * cookiecontrol_admin_settings_validate function.
 *
 * @access public
 * @param mixed $form
 * @param mixed &$form_state
 * @return void
 */
function cookiecontrol_admin_settings_validate($form, &$form_state) {
  // Attempt to load in a specified privacy policy node id
  if ($form_state['values']['cookiecontrol_privacynode'] > 0) {
    $node = node_load($form_state['values']['cookiecontrol_privacynode']);

    // If no node can be loaded give the user a suitable message prompt.
    if (!$node) {
      form_set_error('cookiecontrol_privacynode', t('The specified privacy policy node id does not exist. Leave blank if you have not yet created a policy page.'));
    }
  }
}


/*
  @todo
  The following settings are not yet supported:
  onAccept:function(){},
  onReady:function(){},
  onCookiesAllowed:function(){},
  onCookiesNotAllowed:function(){},
 */